@@ -26,7 +26,6 @@ from pm4py.util.constants import PARAM_MOST_COMMON_VARIANT
 from enum import Enum
 from pm4py.util import exec_utils
 from copy import copy
-import deprecation
 from typing import Optional, Dict, Any, Union, Tuple, List
 import pandas as pd
 
@@ -74,57 +73,6 @@ def apply(df: pd.DataFrame, values: List[str], parameters: Optional[Dict[Union[s
                                        positive=positive, grouped_df=grouped_df)
 
 
-@deprecation.deprecated("2.2.11", "3.0.0", details="Removed")
-def apply_auto_filter(df, parameters=None):
-    """
-    Apply auto filter on end activities
-
-    Parameters
-    -----------
-    df
-        Pandas dataframe
-    parameters
-        Parameters of the algorithm, including:
-            Parameters.CASE_ID_KEY -> Case ID column in the dataframe
-            Parameters.ACTIVITY_KEY -> Column that represents the activity
-            Parameters.DECREASING_FACTOR -> Decreasing factor that should be passed to the algorithm
-
-    Returns
-    -----------
-    df
-        Filtered dataframe
-    """
-    if parameters is None:
-        parameters = {}
-
-    case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
-    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, DEFAULT_NAME_KEY)
-    grouped_df = exec_utils.get_param_value(Parameters.GROUP_DATAFRAME, parameters, None)
-    return_dict = exec_utils.get_param_value(Parameters.RETURN_EA_COUNT, parameters, False)
-    decreasing_factor = exec_utils.get_param_value(Parameters.DECREASING_FACTOR, parameters,
-                                                   filtering_constants.DECREASING_FACTOR)
-
-    most_common_variant = parameters[PARAM_MOST_COMMON_VARIANT] if PARAM_MOST_COMMON_VARIANT in parameters else None
-
-    if most_common_variant is None:
-        most_common_variant = []
-
-    if len(df) > 0:
-        end_activities = get_end_activities(df, parameters=parameters)
-        ealist = end_activities_common.get_sorted_end_activities_list(end_activities)
-        eathreshold = end_activities_common.get_end_activities_threshold(ealist, decreasing_factor)
-
-        return filter_df_on_end_activities_nocc(df, eathreshold, ea_count0=end_activities, case_id_glue=case_id_glue,
-                                                activity_key=activity_key, grouped_df=grouped_df,
-                                                return_dict=return_dict,
-                                                most_common_variant=most_common_variant)
-
-    if return_dict:
-        return df, {}
-
-    return df
-
-
 def filter_df_on_end_activities(df, values, case_id_glue=CASE_CONCEPT_NAME,
                                 activity_key=xes.DEFAULT_NAME_KEY, grouped_df=None, positive=True):
     """
