@@ -15,3 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.algo.transformation.log_to_interval_tree import algorithm, variants
+
+import warnings
+
+warnings.warn("The log_to_interval_tree package will be removed in a future release.")
