@@ -19,7 +19,7 @@ import uuid
 from lxml import etree
 
 from pm4py.objects.petri_net.obj import Marking
-from pm4py.objects.petri_net.obj import PetriNet
+from pm4py.objects.petri_net.obj import PetriNet, ResetNet, InhibitorNet
 from pm4py.objects.petri_net import properties as petri_properties
 from pm4py.util import constants
 
@@ -54,7 +54,10 @@ def export_petri_tree(petrinet, marking, final_marking=None, export_prom5=False,
 
     root = etree.Element("pnml")
     net = etree.SubElement(root, "net")
-    net.set("id", "net1")
+    net.set("id", petrinet.name)
+    netname = etree.SubElement(net, "name")
+    netnametext = etree.SubElement(netname, "text")
+    netnametext.text = petrinet.name
     net.set("type", "http://www.pnml.org/version-2009/grammar/pnmlcoremodel")
     if export_prom5 is True:
         page = net
@@ -168,10 +171,20 @@ def export_petri_tree(petrinet, marking, final_marking=None, export_prom5=False,
             arc_weight = etree.SubElement(inscription, "text")
             arc_weight.text = str(arc.weight)
 
-        for prop_key in arc.properties:
-            element = etree.SubElement(arc_el, prop_key)
+        if isinstance(arc, ResetNet.ResetArc):
+            element = etree.SubElement(arc_el, petri_properties.ARCTYPE)
             element_text = etree.SubElement(element, "text")
-            element_text.text = str(arc.properties[prop_key])
+            element_text.text = petri_properties.RESET_ARC
+        elif isinstance(arc, InhibitorNet.InhibitorArc):
+            element = etree.SubElement(arc_el, petri_properties.ARCTYPE)
+            element_text = etree.SubElement(element, "text")
+            element_text.text = petri_properties.INHIBITOR_ARC
+
+        for prop_key in arc.properties:
+            if prop_key != petri_properties.ARCTYPE:
+                element = etree.SubElement(arc_el, prop_key)
+                element_text = etree.SubElement(element, "text")
+                element_text.text = str(arc.properties[prop_key])
 
     if len(final_marking) > 0:
         finalmarkings = etree.SubElement(net, "finalmarkings")
