@@ -1,3 +1,19 @@
+'''
+    This file is part of PM4Py (More Info: https://pm4py.fit.fraunhofer.de).
+
+    PM4Py is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    PM4Py is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
+'''
 from pm4py.util import constants, exec_utils, xes_constants
 from pm4py.streaming.util.dictio import generator
 from pm4py.streaming.algo.interface import StreamingAlgorithm
@@ -57,7 +73,7 @@ class FootprintsStreamingConformance(StreamingAlgorithm):
              - Parameters.CASE_DICT_ID: identifier of the dictionary hosting the last activity of a case (1)
              - Parameters.DEV_DICT_ID: identifier of the dictionary hosting the deviations (2)
         """
-        dict_variant = exec_utils.get_param_value(Parameters.DICT_VARIANT, parameters, generator.Variants.CLASSIC)
+        dict_variant = exec_utils.get_param_value(Parameters.DICT_VARIANT, parameters, generator.Variants.THREAD_SAFE)
         case_dict_id = exec_utils.get_param_value(Parameters.CASE_DICT_ID, parameters, 0)
         dev_dict_id = exec_utils.get_param_value(Parameters.DEV_DICT_ID, parameters, 1)
         parameters_case_dict = copy(parameters)
@@ -101,16 +117,16 @@ class FootprintsStreamingConformance(StreamingAlgorithm):
         activity
             Activity
         """
-        if case not in self.case_dict:
+        if case not in self.case_dict.keys():
             self.dev_dict[case] = 0
         if activity in self.activities:
-            if case not in self.case_dict:
+            if case not in self.case_dict.keys():
                 self.verify_start_case(case, activity)
             else:
                 self.verify_intra_case(case, activity)
             self.case_dict[case] = activity
         else:
-            self.dev_dict[case] += 1
+            self.dev_dict[case] = int(self.dev_dict[case]) + 1
             self.message_activity_not_possible(activity, case)
 
     def verify_intra_case(self, case, activity):
@@ -127,7 +143,7 @@ class FootprintsStreamingConformance(StreamingAlgorithm):
         prev = self.case_dict[case]
         df = (prev, activity)
         if df not in self.all_fps:
-            self.dev_dict[case] += 1
+            self.dev_dict[case] = int(self.dev_dict[case]) + 1
             self.message_footprints_not_possible(df, case)
 
     def verify_start_case(self, case, activity):
@@ -142,7 +158,7 @@ class FootprintsStreamingConformance(StreamingAlgorithm):
             Activity
         """
         if activity not in self.start_activities:
-            self.dev_dict[case] += 1
+            self.dev_dict[case] = int(self.dev_dict[case]) + 1
             self.message_start_activity_not_possible(activity, case)
 
     def get_status(self, case):
@@ -159,8 +175,8 @@ class FootprintsStreamingConformance(StreamingAlgorithm):
         boolean
             Boolean value (True if there are no deviations)
         """
-        if case in self.case_dict:
-            num_dev = self.dev_dict[case]
+        if case in self.case_dict.keys():
+            num_dev = int(self.dev_dict[case])
             if num_dev == 0:
                 return True
             else:
@@ -182,12 +198,12 @@ class FootprintsStreamingConformance(StreamingAlgorithm):
         boolean
             Boolean value (True if there are no deviations)
         """
-        if case in self.case_dict:
+        if case in self.case_dict.keys():
             curr = self.case_dict[case]
             if curr not in self.end_activities:
                 self.message_end_activity_not_possible(curr, case)
-                self.dev_dict[case] += 1
-            num_dev = self.dev_dict[case]
+                self.dev_dict[case] = int(self.dev_dict[case]) + 1
+            num_dev = int(self.dev_dict[case])
             del self.case_dict[case]
             del self.dev_dict[case]
             if num_dev == 0:
